import React from "react";
import { Layout } from "antd";
import { useLocation, Outlet, useNavigate } from "react-router-dom";
import { useModel } from "@/store";
import useRoute from "@/routes/hooks/useRoute";
import SiderBar from "./components/SiderBar";
import Header from "./components/Header";
import Container from "./components/Container";

import "./style.less";

export default (props) => {
  const { theme } = useModel("system");
  const { user, menus } = useModel("user");
  const navigate = useNavigate();
  const location = useLocation();
  const { meta } = useRoute() || {};
  const { noLayout = false, noSiderBar = false, noFooter = false } = meta || {};

  // 非管理人员只能看到卡片
  React.useEffect(() => {
    if ("1" !== user?.orgId && "/appCenter" !== location.pathname) {
      navigate("/appCenter", { replace: true });
    }
  }, [location.pathname, user?.orgId]);

  return noLayout ? (
    <Outlet />
  ) : (
    <Layout className={theme} style={{ height: "100vh" }}>
      <Header theme={theme} user={user} />
      <Layout style={{ height: "calc(100vh - var(--header-height))" }}>
        {!noSiderBar && (
          <SiderBar theme={theme} menus={menus} location={location} />
        )}
        <Container location={location} noFooter={noFooter} />
      </Layout>
    </Layout>
  );
};
