import React from "react";
import md5 from "md5";
import { Button, Form, Input } from "antd";
import { login } from "@/services/login";

export default (props) => {
  const { onSuccess, mode, appid } = props;
  const [form] = Form.useForm();
  const [loading, setLoading] = React.useState(false);
  const onFinish = (values) => {
    const formData = new FormData();
    formData.append("name", values.name);
    formData.append("pwd", md5(values.pwd));
    if (mode) {
      formData.append("mode", mode);
    }
    formData.append("client", appid);

    setLoading(true);
    login(formData)
      .then((res) => {
        onSuccess(res);
        setLoading(false);
      })
      .catch((err) => {
        console.log('----err--', err);
        setLoading(false);
      });
  };
  return (
    <Form form={form} layout="vertical" onFinish={onFinish}>
      <Form.Item label="用户名" name="name" required>
        <Input placeholder="请输入用户名" style={{ borderRadius: "4px" }} />
      </Form.Item>
      <Form.Item label="密 码" name="pwd" required>
        <Input.Password
          placeholder="请输入密码"
          style={{ borderRadius: "4px" }}
        />
      </Form.Item>
      <Form.Item>
        <Button
          type="primary"
          size="large"
          style={{ width: "100%", marginTop: "24px", borderRadius: "4px" }}
          loading={loading}
          htmlType="submit"
        >
          登录
        </Button>
      </Form.Item>
    </Form>
  );
};
