import React, { useEffect } from "react";
import { Button } from "antd";
import { Helmet } from "react-helmet";
import { useNavigate, useSearchParams } from "react-router-dom";
import { useModel } from "@/store";
import LoginForm from "./LoginForm";
import LoginEffect from "./Effect";
import "./style.less";

const year = new Date().getFullYear();

export default (props) => {
  const { app } = useModel("system");
  const navigate = useNavigate();
  const [searchParams] = useSearchParams();

  const baseUrl = import.meta.env.BASE_URL;
  const title = `欢迎使用${app.fullName}`;
  const copyright = `${app.company} @ ${year}`;

  useEffect(() => {
    const oScript = document.createElement("script");
    oScript.type = "text/javascript";
    oScript.onload = () => {
      particlesJS.load(
        "particles-js",
        `${baseUrl}particles/particles.json`,
        function () {
          console.log("callback - particles.js config loaded");
        }
      );
    };
    document.querySelector("head").appendChild(oScript);
    oScript.src = `${baseUrl}particles/particles.min.js`;

    return () => {
      document.querySelector("head").removeChild(oScript);
    };
  }, []);

  const onSuccess = ({ ticket }) => {
    if (searchParams.get("redirect")) {
      const redirect = decodeURIComponent(searchParams.get("redirect"));
      let herf = "";
      if (redirect.indexOf("#") === -1) {
        herf = redirect + `#/?ticket=${ticket}`;
      } else if (redirect.indexOf("?") > -1) {
        herf = redirect + `ticket=${ticket}`;
      } else {
        herf = redirect + `?ticket=${ticket}`;
      }
      window.location.href = herf;
    } else if (searchParams.get("back")) {
      navigate(-1);
    } else {
      navigate("/");
    }
  };

  return (
    <div className="login-page">
      <Helmet>
        <title>{app.fullName}</title>
      </Helmet>
      <div id="particles-js"></div>
      <div className="login-page-container">
        <div className="login-card">
          <div className="login-card-left">
            <div className="login-form-box">
              <div className="login-form">
                <h2>
                  <span>登录系统</span>
                </h2>
                <div className="login-subtitle">{title}</div>
                <LoginForm
                  mode={searchParams.get("mode")}
                  appid={searchParams.get("appid")}
                  onSuccess={onSuccess}
                />
              </div>
            </div>
            <div className="login-copyright">{copyright}</div>
          </div>
          <div className="login-card-right">
            <LoginEffect />
          </div>
        </div>
      </div>
    </div>
  );
};
