import React from "react";
import { Modal, Form, Input, Button, Select } from "antd";
import useBool from "@/utils/hooks/useBool";
// import { postSysUser } from "@/services/sysuser";
import md5 from "md5";

const { Option } = Select;

const formItemLayout = {
  labelCol: {
    xs: { span: 24 },
    sm: { span: 8 },
  },
  wrapperCol: {
    xs: { span: 24 },
    sm: { span: 16 },
  },
};
const tailFormItemLayout = {
  wrapperCol: {
    xs: {
      span: 24,
      offset: 0,
    },
    sm: {
      span: 16,
      offset: 8,
    },
  },
};

const defaultPass = "123456";

export default (props) => {
  const { user, onSuccess, onCancel, roleList = [], ...leftProps } = props;

  const [loading, startLoading, cancelLoading] = useBool();
  const [form] = Form.useForm();

  const onFinish = (values) => {
    const password = md5(defaultPass);
    const rolesList = (values.rolesList || []).map((x) => ({ roleId: x }));
    const data = {
      ...user,
      ...values,
      password,

      rolesList,
      userId: user.userId,
    };

    startLoading();
    // postSysUser(data)
    //   .then((res) => {
    //     onSuccess();
    //     cancelLoading();
    //   })
    //   .catch(() => {
    //     cancelLoading();
    //   });
  };

  React.useEffect(() => {
    if (user?.userId) {
      form.setFieldsValue({
        account: user.account || undefined,
        rolesList: user.rolesList.map((x) => x.roleId),
      });
    }
  }, [user, form]);

  return (
    <Modal
      title="账号维护"
      footer={null}
      width={600}
      onCancel={onCancel}
      {...leftProps}
    >
      <Form
        {...formItemLayout}
        form={form}
        scrollToFirstError
        style={{ width: "480px" }}
        onFinish={onFinish}
      >
        <Form.Item
          name="account"
          label="账号"
          rules={[
            {
              required: true,
              message: "请填写姓名",
            },
          ]}
        >
          <Input />
        </Form.Item>
        <Form.Item name="rolesList" label="角色">
          <Select
            mode="multiple"
            allowClear
            style={{ width: "100%" }}
            placeholder="请选择角色"
          >
            {roleList.map((role) => (
              <Option key={role.roleId}>{role.name}</Option>
            ))}
          </Select>
        </Form.Item>
        <Form.Item
          label="密码"
        >
          <div>{`默认密码 ${defaultPass}`}</div>
        </Form.Item>
        <Form.Item {...tailFormItemLayout}>
          <Button loading={loading} type="primary" htmlType="submit">
            保存
          </Button>
          <Button style={{ marginLeft: "2em" }} onClick={onCancel}>
            取消
          </Button>
        </Form.Item>
      </Form>
    </Modal>
  );
};
