import { useState, useRef } from "react";
import { defaultRoutes, authRoutes, mergeAuthRoutes } from "@/routes/routes";
import { getMenuItems } from "@/routes/menus";
import { getAuthedRoutes } from "@/routes/permissions";
import { currentUser } from "@/services/sys_user";

export default function useUser() {
  const [user, setUser] = useState();
  const menusRef = useRef();
  const routesRef = useRef();

  const getCurrentUser = (params) =>
    new Promise((resolve, reject) => {
      currentUser(params)
        .then((res) => {
          const { user } = res;
          const permissions = (user.resourcesList || []).map((x) => x.resourceCode);

          // authRoutes 是所有待验证授权的路由
          // authedRoutes 是已经被授权的路由
          const authedRoutes = getAuthedRoutes(authRoutes, permissions);

          menusRef.current = getMenuItems(authedRoutes);
          routesRef.current = mergeAuthRoutes(defaultRoutes, authedRoutes);

          setUser(user);
          resolve(user);
        })
        .catch(reject);
    });

  return {
    user,
    setUser,
    getCurrentUser,
    menus: menusRef.current || [],
    routes: routesRef.current || [],
  };
}
